@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """test_site URL Configuration
 
 The `urlpatterns` list routes URLs to views. For more information please see:
@@ -13,10 +14,10 @@ Including another URLconf
     1. Import the include() function: from django.urls import include, path
     2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
 """
-from django.contrib import admin
-from django.urls import path, include
+from __future__ import absolute_import, print_function, unicode_literals
 
-urlpatterns = [
-    path('admin/', admin.site.urls),
-    path('polls/', include('polls.urls')),
-]
+from django.contrib import admin
+from django.urls import include, path
+
+
+urlpatterns = [path("admin/", admin.site.urls), path("polls/", include("polls.urls"))]
