@@ -7,14 +7,12 @@ from django_sorcery import utils
 
 
 class TestUtils(TestCase):
-
     def test_suppress(self):
 
         with utils.suppress(AssertionError):
             assert 1 == 2
 
     def test_setdefaultattr(self):
-
         class Dummy(object):
             pass
 
@@ -37,3 +35,7 @@ class TestUtils(TestCase):
         value = utils.make_args("abc", kw="something")
 
         self.assertEqual(value, ("abc", {"kw": "something"}))
+
+    def test_lower(self):
+        self.assertEqual(utils.lower("HELLO"), "hello")
+        self.assertEqual(utils.lower(5), 5)
